Index: /trunk/RESULTATS/eof_NCEP_an.m
===================================================================
--- /trunk/RESULTATS/eof_NCEP_an.m	(revision 26)
+++ /trunk/RESULTATS/eof_NCEP_an.m	(revision 27)
@@ -8,5 +8,5 @@
 %
 % le programme permet egalement de visualiser les resultats. Voir le doc
-% .pdf joint pour l'interpretation de cette visualisation. 
+% .pdf joint pour l'interpretation de cette visualisation.
 %
 % Date: Avril-Mai 2008
@@ -18,10 +18,10 @@
 % ======
 %
-% ``eof_NCEP_an`` 
+% ``eof_NCEP_an``
 %
 % DESCRIPTION
 % ===========
 %
-% ``eof_NCEP_an`` lit les fichiers 
+% ``eof_NCEP_an`` lit les fichiers
 % ``../DONNEES/lsmask_tropatl_PacandMedblancs.mat``
 % et ``../DONNEES/skt.mon.tropatl.mat``.
@@ -34,9 +34,12 @@
 %
 % ``eof_NCEP_an`` affiche trois figures :
+%
 %  - ++
+%
 %  - ++
+%
 %  - valeurs propres de la matrice de covariance
 %
-% ``eof_NCEP_an`` sauve ces images dans ``./eof_SSTan_tropAlt30N-20S++_[123].eps``.
+% ``eof_NCEP_an`` sauve ces images dans ``./eof_SSTan_tropAlt30N-20S_[123].ps``.
 %
 % ++
@@ -77,5 +80,5 @@
 % tester la branche NetCDF
 %
-% sous octave, triangle bizarre dans la dernière barre du graphique valeurs 
+% sous octave, triangle bizarre dans la dernière barre du graphique valeurs
 % propres.
 %
@@ -84,4 +87,13 @@
 %
 % $Id$
+%
+% - fplod 2009-08-26T10:26:35Z aedon.locean-ipsl.upmc.fr (Darwin)
+%
+%  * remplacement de ``eps`` par ``ps` pour pouvoir imprimer les figures
+%    produites par ``octave``
+%
+% - jmignot 2009-08-25
+%
+%  * suppression d'appel à contlab et colorbartype sous octave
 %
 % - fplod 2009-08-25T10:40:16Z aedon.locean-ipsl.upmc.fr (Darwin)
@@ -98,6 +110,6 @@
 % - fplod 2009-08-21T15:04:16Z aedon.locean-ipsl.upmc.fr (Darwin)
 %
-%   * as octave save default format is ASCII and no default extension 
-%     while matlab save default format is MAT v5 mat-file (little endian) and 
+%   * as octave save default format is ASCII and no default extension
+%     while matlab save default format is MAT v5 mat-file (little endian) and
 %     default extension is ``.mat``, write more precise save instruction
 %   * add header
@@ -130,5 +142,5 @@
 
 nannees=60;
-   
+
 repertoire=[ '..' filesep 'DONNEES' filesep ] % a adapter a chaque cas: chemin d acces aux donnees
 
@@ -137,5 +149,5 @@
 file='lsmask_tropatl_PacandMedblancs.mat'
    load([repertoire file]);
-  ny=size(mask,1); nx=size(mask,2); % dimensions spatiales des tableaux 
+  ny=size(mask,1); nx=size(mask,2); % dimensions spatiales des tableaux
 
 % Data
@@ -146,5 +158,5 @@
   load([repertoire2 file]); % chargement des donnees
 
-   
+
   %SI NETCDF
   %repertoire2=[repertoire 'NETCDF' filesep]% a adapter a chaque cas: chemin d acces aux donnees
@@ -152,5 +164,5 @@
   % f=netcdf([repertoire file],'nowrite');
   % tab=f{'skt'}(:,:,:);
-  
+
 
    tab=permute(tab,[2 3 1]);% permutation des dimensions pour organiser le tableau sous la forme [lat lon temps]
@@ -179,5 +191,5 @@
 %----------------
 %Si on veut éventuellement attribuer un poids différent aux différents
-%points spatiaux, on le fait ici. 
+%points spatiaux, on le fait ici.
 
 % Préparation du zoom géographique: sur le masque, j'identifie les points
@@ -187,5 +199,5 @@
 limite_latS=-20; %limite du domaine d'etuade en latitude
 limite_latN=30; %limite du domaine d'etuade en latitude
-lat2D=repmat(lat,[1 size(mask,2)]); 
+lat2D=repmat(lat,[1 size(mask,2)]);
 mask(lat2D>limite_latN&mask==0)=4;
 mask(lat2D<limite_latS&mask==0)=4;
@@ -219,24 +231,24 @@
 % matrice de covariance:
   C = Z * Z';
-%  eval(['save ' repertoire 'MatCov_SST_tropAtl' num2str(limite_latN) 'N' num2str(limite_latS) 'S.asc C -ascii']) 
-  
-% diagonalisation  
-  [E,Lambda] = eig(C); 
-   % Lambda est la matrice diagonale des valeurs propres et E la matrice dont les colonnes sont les vecteurs propres correspondants.  
+%  eval(['save ' repertoire 'MatCov_SST_tropAtl' num2str(limite_latN) 'N' num2str(limite_latS) 'S.asc C -ascii'])
+
+% diagonalisation
+  [E,Lambda] = eig(C);
+   % Lambda est la matrice diagonale des valeurs propres et E la matrice dont les colonnes sont les vecteurs propres correspondants.
    % Soit Z*E = E*Lambda
-   % Les vecteurs propres sont appelés les EOF. Chaque EOF peut être considéré comme une carte de l'espace physique.    
-
-   
- %% 
+   % Les vecteurs propres sont appelés les EOF. Chaque EOF peut être considéré comme une carte de l'espace physique.
+
+
+ %%
  %%%% calcul de la matrice donnant les pourcentages de variance
 Lambda = diag(Lambda);
 pctg_var = round(Lambda / sum(Lambda) * 1000) / 10;
 
- 
+
  %On definit les composantes principales de Q comme la decomposition du signal decrit par Q sur les EOF E.
 
    P = Z' * E;
-    
-%%   
+
+%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -288,13 +300,13 @@
 %niveaux de couleurs
   lev=[-2:.02:2];
-  clip_lev=[-0.06 0.06]
+  clip_lev=[-0.06 0.06];
 
 figure(1);
 initfig;
-figure(2); 
+figure(2);
 initfig;
 
 for i=1:4
-    
+
    %subplot(4,2,2*i-1)
    ifigure=1;
@@ -309,5 +321,5 @@
    z=squeeze(TABEOF(:,:,i));
    contourf(x,y,z,lev);
-   caxis(clip_lev)
+   caxis(clip_lev);
    hold on
    whorldmap
@@ -329,5 +341,5 @@
   if (run_octave == 0)
     hpal=jet(100); %carte des couleurs: du bleu au rouge par defaut.
-    pos1=get(gca,'Position')
+    pos1=get(gca,'Position');
     pos=[pos1(1) pos1(2)-.075 pos1(3) .013];
     colorbartype(pos,lev,1,clip_lev,hpal,0);
@@ -336,7 +348,7 @@
     colorbar('East')
   end;
-  
+
    % sauvegarde de la figure
-   printer='eps';
+   printer='ps';
    print_printer=['-d', printer];
    fullfilename=['.' filesep nomfic num2str(limite_latN) 'N' num2str(limite_latS) 'S_' , num2str(ifigure) '.' printer];
@@ -344,5 +356,5 @@
    clear fullfilename;
    clear printer;
-   
+
    %subplot(4,2,2*i)
    ifigure=2;
@@ -357,5 +369,5 @@
 
    % sauvegarde de la figure
-   printer='eps';
+   printer='ps';
    print_printer=['-d', printer];
    fullfilename=['.' filesep nomfic num2str(limite_latN) 'N' num2str(limite_latS) 'S_' , num2str(ifigure) '.' printer];
@@ -369,5 +381,5 @@
 % Graphe pourcentages de variance expliqué
 ifigure=3;
-figure(ifigure); 
+figure(ifigure);
 bar(flipud(pctg_var))
 xlim([0 10])
@@ -377,5 +389,5 @@
 
 % sauvegarde de la figure
-printer='eps';
+printer='ps';
 print_printer=['-d', printer];
 fullfilename=['.' filesep nomfic num2str(limite_latN) 'N' num2str(limite_latS) 'S_' , num2str(ifigure) '.' printer];
Index: /trunk/RESULTATS/regandsignif_seriestemporelles.m
===================================================================
--- /trunk/RESULTATS/regandsignif_seriestemporelles.m	(revision 26)
+++ /trunk/RESULTATS/regandsignif_seriestemporelles.m	(revision 27)
@@ -28,5 +28,5 @@
 %
 % ``regandsignif_seriestemporelles`` sauve cette image dans 
-% ``./eof_SSTan_tropAtl30N-20S.mat_regandsignif_seriestemporelles_1.eps``.
+% ``./eof_SSTan_tropAtl30N-20S.mat_regandsignif_seriestemporelles_1.ps``.
 %
 % EXAMPLES
@@ -233,5 +233,5 @@
 
 % sauvegarde de la figure
-printer='eps';
+printer='ps';
 print_printer=['-d', printer];
 fullfilename=['.' filesep file '_' mfilename '_'  num2str(ifigure) '.' printer];

Index: /trunk/RESULTATS/carteetstd_SST.m
===================================================================
--- /trunk/RESULTATS/carteetstd_SST.m	(revision 26)
+++ /trunk/RESULTATS/carteetstd_SST.m	(revision 27)
@@ -1,5 +1,5 @@
 %CARTEETSTD_SST permet de visualiser les cartes mensuelles moyennes
 % de temperature de surface       
 % ainsi que les cartes annuelles moyennes et les ecart type
 % correspondants
 
@@ -19,5 +19,5 @@
 % ``carteetstd_SST`` permet de visualiser les cartes mensuelles moyennes
 % de temperature de surface
 % ainsi que les cartes annuelles moyennes et les ecart type
 % correspondants.
 %
@@ -36,5 +36,5 @@
 % (figure 3).
 %
-% ``carteetstd_SST`` sauve ces images dans ``./carteetstd_SST_[123].eps``.
+% ``carteetstd_SST`` sauve ces images dans ``./carteetstd_SST_[123].ps``.
 %
 % EXAMPLES
@@ -70,4 +70,11 @@
 % .. _contlab.m : contlab.m.html
 %
+%
+% KNOWN PROBLEMS
+% ==============
+%
+% pb avec les diacritiques à l'impression de .ps dans le titres des figures 
+% sous octave : é se transforme en o barré.
+%
 % TODO
 % ====
@@ -80,7 +87,18 @@
 % $Id$
 %
+% - fplod 2009-08-26T09:56:51Z aedon.locean-ipsl.upmc.fr (Darwin)
+%   
+%  * nom des mois à la place du numéro dans les titres
+%  * remplacement de ``eps`` par ``ps` pour pouvoir imprimer les figures 
+%    produites par ``octave``
+%
+%
+% - jmignot 2009-08-25
+%
+%  * suppression d'appel à contlab et colorbartype sous octave
+%
 % - fplod 2009-08-25T10:40:16Z aedon.locean-ipsl.upmc.fr (Darwin)
 %
-%    * modif commentaires liée au dernier chgt de Juliette
+%  * modif commentaires liée au dernier chgt de Juliette
 %
 % - jmignot 2009-08-25
@@ -142,5 +160,5 @@
 %  MANIPULATIONS TEMPORELLES: MOYENNES 
 %---------------------------------------------------
-tab=reshape(tab,size(tab,1),size(tab,2),12,nannees); %organisation du tableau sous la forme [lat lon mois annees]
+tab=reshape(tab,size(tab,1),size(tab,2),12,nannees); %organisation du tableau sous la forme [lat lon mois années]
 
 % Construction de moyennes annuelles
@@ -152,10 +170,10 @@
 tab_mens=squeeze(mean(tab,4));
 
-%calcul des ecart-types
+%calcul des écart-types
 %------------------------
-%ecart-type mensuel moyen: 
+%écart-type mensuel moyen: 
 std_mens=squeeze(std(tab_mens,0,3));
 
-%ecart-type interannuel moyen: 
+%écart-type interannuel moyen: 
 std_an=squeeze(std(tab_an,0,3));
 
@@ -212,5 +230,7 @@
   
   %titre: nom de chaque mois
-  title(['mois ' num2str(iplot)])
+  cmois = datestr(datenum([2000 iplot 1 00 00 00]), 'mmm');
+  title(cmois);
+  clear cmois;
   
 end;
@@ -227,5 +247,5 @@
 
 % sauvegarde de la figure
-printer='eps';
+printer='ps';
 print_printer=['-d', printer];
 fullfilename=['./',mfilename,'_',num2str(ifigure),'.',printer];
@@ -279,5 +299,5 @@
   end;
 
-  %titre: numero de l'annee
+  %titre: numéro de l'année
   title(['annee ' num2str(iplot+1948-1)])
 end; 
@@ -294,5 +314,5 @@
 
 % sauvegarde de la figure
-printer='eps';
+printer='ps';
 print_printer=['-d', printer];
 fullfilename=['./',mfilename,'_',num2str(ifigure),'.',printer];
@@ -303,5 +323,5 @@
 
 
-% ecart type
+% écart type
 %-----------
 
@@ -313,5 +333,5 @@
 initfig; 
 
-%ecart-type mensuel moyen
+%écart-type mensuel moyen
 
 %niveaux de couleurs
@@ -355,5 +375,5 @@
 
 
-%ecart-type interannuel  moyen
+%écart-type interannuel  moyen
 
 %niveaux de couleurs
@@ -379,5 +399,5 @@
   ylabel('latitude')
 
-title('ecart-type interannuel')
+title('écart-type interannuel')
 %barre de couleur
 if (run_octave == 0)
@@ -393,5 +413,5 @@
 
 % sauvegarde de la figure
-printer='eps';
+printer='ps';
 print_printer=['-d', printer];
 fullfilename=['./',mfilename,'_',num2str(ifigure),'.',printer];
@@ -1,5 +1,5 @@
 %CARTEETSTD_SST permet de visualiser les cartes mensuelles moyennes
 % de temperature de surface       
-% ainsi que les cartes annuelles moyennes et les ecart type
+% ainsi que les cartes annuelles moyennes et les écart type
 % correspondants
 
@@ -19,5 +19,5 @@
 % ``carteetstd_SST`` permet de visualiser les cartes mensuelles moyennes
 % de temperature de surface
-% ainsi que les cartes annuelles moyennes et les ecart type
+% ainsi que les cartes annuelles moyennes et les écart type
 % correspondants.
 %